-----------------------------------------------------------------------------------------------
-- Client Lua Script for TimeKeeper
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "GameLib" 

-----------------------------------------------------------------------------------------------
-- TimeKeeper Module Definition
-----------------------------------------------------------------------------------------------
local TimeKeeper = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function TimeKeeper:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 
	o.config = {}
	o.config.militaryTime = false
    -- initialize variabl-es here

    return o
end

function TimeKeeper:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureButton, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- TimeKeeper OnLoad
-----------------------------------------------------------------------------------------------
function TimeKeeper:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("TimeKeeper.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- TimeKeeper OnDocLoaded
-----------------------------------------------------------------------------------------------
function TimeKeeper:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "TimeKeeperForm", nil, self)
		self.wndClock = Apollo.LoadForm(self.xmlDoc, "clockForm", nil, self)
		self.clock = self.wndClock:FindChild("clock")
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)
		self.wndClock:Show(false, true)
		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("timekeeper", "OnTimeKeeperOn", self)

		self.timer = ApolloTimer.Create(1, true, "OnTimer", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- TimeKeeper Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/timekeeper"
function TimeKeeper:OnTimeKeeperOn()
	self.wndMain:Show(true) -- show the window
end

-- on timer
function TimeKeeper:OnTimer()
    timeFormatted = nil
    if self.config.militaryTime == false then
		timeFormatted = os.date('%X')
    else
		timeFormatted = os.date('%H:%M:%S')
	end
	self.clock:SetText(timeFormatted)
	if self.wndClock:IsVisible() == false then
		self.wndClock:Show(true)
	end
end


-----------------------------------------------------------------------------------------------
-- TimeKeeperForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function TimeKeeper:OnOK()
	self.wndMain:Show(false) -- hide the window
end

-- when the Cancel button is clicked
function TimeKeeper:OnCancel()
	self.wndMain:Show(false) -- hide the window
end

function TimeKeeper:OnCheckboxChange( wndHandler, wndControl, eMouseButton)
	self.config[wndControl:GetName()] = wndControl:IsChecked()
end

-----------------------------------------------------------------------------------------------
-- TimeKeeper Instance
-----------------------------------------------------------------------------------------------
local TimeKeeperInst = TimeKeeper:new()
TimeKeeperInst:Init()
